<?php
session_start();
header('Content-Type: application/json');

// Verificar autenticación
if (!isset($_SESSION['user_id'])) {
    echo json_encode(['error' => 'No autenticado']);
    exit();
}

$user_id = $_SESSION['user_id'];

// Conexión a la base de datos
require_once 'config.php';

// Obtener conversaciones del usuario
$query = "
    SELECT 
        u.id, u.name, u.phone,
        (SELECT message FROM messages 
         WHERE (sender_id = ? AND receiver_id = u.id) OR (sender_id = u.id AND receiver_id = ?) 
         ORDER BY timestamp DESC LIMIT 1) as last_message,
        (SELECT timestamp FROM messages 
         WHERE (sender_id = ? AND receiver_id = u.id) OR (sender_id = u.id AND receiver_id = ?) 
         ORDER BY timestamp DESC LIMIT 1) as last_timestamp,
        (SELECT COUNT(*) FROM messages 
         WHERE sender_id = u.id AND receiver_id = ? AND `read` = 0) as unread_count
    FROM 
        users u
    WHERE 
        u.id != ? AND
        EXISTS (
            SELECT 1 FROM messages 
            WHERE (sender_id = ? AND receiver_id = u.id) OR (sender_id = u.id AND receiver_id = ?)
        )
    ORDER BY 
        last_timestamp DESC
";

$stmt = $conn->prepare($query);
$stmt->bind_param("iiiiiiii", $user_id, $user_id, $user_id, $user_id, $user_id, $user_id, $user_id, $user_id);
$stmt->execute();
$result = $stmt->get_result();

$chats = [];
while ($row = $result->fetch_assoc()) {
    // Formatear timestamp
    if ($row['last_timestamp']) {
        $timestamp = strtotime($row['last_timestamp']);
        $now = time();
        $today = strtotime('today');
        
        if ($timestamp >= $today) {
            // Hoy
            $row['time_formatted'] = date('H:i', $timestamp);
        } else if ($timestamp >= ($today - 86400)) {
            // Ayer
            $row['time_formatted'] = 'Ayer';
        } else if ($timestamp >= ($today - 6 * 86400)) {
            // Esta semana
            $row['time_formatted'] = date('D', $timestamp);
        } else {
            // Más de una semana
            $row['time_formatted'] = date('d/m/Y', $timestamp);
        }
    } else {
        $row['time_formatted'] = '';
    }
    
    $chats[] = $row;
}

echo json_encode($chats);

$stmt->close();
$conn->close();
?>