<?php
// get_new_messages.php
session_start();
header('Content-Type: application/json');
define('OFFLINE_THRESHOLD_SECONDS', 60);

if (!isset($_SESSION['user_id'])) { echo json_encode(['status' => 'error', 'message' => 'No autenticado']); exit(); }
$user_id = $_SESSION['user_id'];

if (!isset($_GET['other_user_id']) || !is_numeric($_GET['other_user_id']) || intval($_GET['other_user_id']) <=0) { echo json_encode(['status' => 'error', 'message' => 'ID de usuario inválido (other_user_id)']); exit(); }
$other_user_id = intval($_GET['other_user_id']);

$last_message_id = isset($_GET['last_message_id']) && is_numeric($_GET['last_message_id']) ? intval($_GET['last_message_id']) : 0;

require_once 'config.php';

// Actualizar MI estado
$update_my_status_query = "INSERT INTO user_status (user_id, status, last_activity) VALUES (?, 'online', NOW()) ON DUPLICATE KEY UPDATE status = 'online', last_activity = NOW()";
$update_my_stmt = $conn->prepare($update_my_status_query); if ($update_my_stmt) { $update_my_stmt->bind_param("i", $user_id); $update_my_stmt->execute(); $update_my_stmt->close(); } else { error_log("Get_new_messages: Error preparing update my status: " . $conn->error); }

// Inicialización
$new_messages = []; $read_by_other_ids = []; $current_last_received_id = $last_message_id; $other_user_current_status = 'offline';

// Obtener nuevos mensajes RECIBIDOS
$messages_query = "SELECT id, sender_id, receiver_id, message, type, file_url, file_name, file_size, file_type, timestamp, `read`, delivered FROM messages WHERE id > ? AND sender_id = ? AND receiver_id = ? AND deleted = 0 ORDER BY id ASC";
$messages_stmt = $conn->prepare($messages_query); $ids_just_received = [];
if ($messages_stmt) { $messages_stmt->bind_param("iii", $last_message_id, $other_user_id, $user_id); if ($messages_stmt->execute()) { $messages_result = $messages_stmt->get_result(); while ($row = $messages_result->fetch_assoc()) { $new_messages[] = $row; $ids_just_received[] = $row['id']; if ($row['id'] > $current_last_received_id) $current_last_received_id = $row['id']; } } else { error_log("Get_new_messages: Error executing get new messages: " . $messages_stmt->error); } $messages_stmt->close(); } else { error_log("Get_new_messages: Error preparing get new messages: " . $conn->error); }

// Marcar como LEÍDOS
if (!empty($ids_just_received)) { $placeholders = implode(',', array_fill(0, count($ids_just_received), '?')); $types = str_repeat('i', count($ids_just_received)); $update_read_query = "UPDATE messages SET `read` = 1 WHERE receiver_id = ? AND sender_id = ? AND id IN ($placeholders) AND `read` = 0"; $update_stmt = $conn->prepare($update_read_query); if ($update_stmt) { $params = array_merge([$user_id, $other_user_id], $ids_just_received); $types = "ii" . $types; $update_stmt->bind_param($types, ...$params); if (!$update_stmt->execute()) { error_log("Get_new_messages: Error executing mark as read: " . $update_stmt->error); } $update_stmt->close(); } else { error_log("Get_new_messages: Error preparing mark as read: " . $conn->error); } }

// Obtener IDs de MIS mensajes leídos por el OTRO
$read_status_query = "SELECT id FROM messages WHERE sender_id = ? AND receiver_id = ? AND `read` = 1 ORDER BY id DESC LIMIT 200";
$read_status_stmt = $conn->prepare($read_status_query);
if ($read_status_stmt) { $read_status_stmt->bind_param("ii", $user_id, $other_user_id); if ($read_status_stmt->execute()) { $read_result = $read_status_stmt->get_result(); while ($row = $read_result->fetch_assoc()) $read_by_other_ids[] = $row['id']; } else { error_log("Get_new_messages: Error executing get read status: " . $read_status_stmt->error); } $read_status_stmt->close(); } else { error_log("Get_new_messages: Error preparing get read status: " . $conn->error); }

// Obtener estado del OTRO usuario
$status_query = "SELECT status, last_activity FROM user_status WHERE user_id = ? LIMIT 1";
$status_stmt = $conn->prepare($status_query); $other_user_last_activity_ts = null;
if ($status_stmt) { $status_stmt->bind_param("i", $other_user_id); if ($status_stmt->execute()) { $status_result = $status_stmt->get_result(); $fetched_status = $status_result->fetch_assoc(); if ($fetched_status) { $db_status = $fetched_status['status']; $db_last_activity = $fetched_status['last_activity']; $other_user_last_activity_ts = $db_last_activity ? strtotime($db_last_activity) : null; if ($db_status === 'online' && $other_user_last_activity_ts && (time() - $other_user_last_activity_ts) <= OFFLINE_THRESHOLD_SECONDS) $other_user_current_status = 'online'; else $other_user_current_status = 'offline'; } else $other_user_current_status = 'offline'; } else { error_log("Get_new_messages: Error executing get user status: " . $status_stmt->error); } $status_stmt->close(); } else { error_log("Get_new_messages: Error preparing get user status: " . $conn->error); }

$conn->close();

// Enviar respuesta JSON
echo json_encode([
    'status' => 'success',
    'messages' => $new_messages,
    'read_by_other' => $read_by_other_ids,
    'user_status' => [ 'status' => $other_user_current_status, 'last_activity_timestamp' => $other_user_last_activity_ts ],
    'last_processed_id' => $current_last_received_id
]);
?>