<?php
session_start();
// Redirigir si ya está autenticado
if (isset($_SESSION['user_id'])) {
    header('Location: dashboard.php');
    exit();
}

// Procesar el formulario si se envió
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    require_once 'config.php';
    
    $country_code = isset($_POST['country_code']) ? $conn->real_escape_string($_POST['country_code']) : '57';
    $phone_number = $conn->real_escape_string($_POST['phone']);
    $name = isset($_POST['name']) ? $conn->real_escape_string($_POST['name']) : '';
    
    // Formatear número de teléfono con código de país
    if (strpos($phone_number, '+') === 0) {
        $phone = $phone_number; // Ya tiene formato completo
    } else {
        $phone = '+' . $country_code . $phone_number;
    }
    
    // Verificar si el usuario existe
    $query = "SELECT id, name FROM users WHERE phone = ?";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("s", $phone);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        // Usuario existente
        $user = $result->fetch_assoc();
        
        // Actualizar última sesión
        $update_query = "UPDATE users SET last_login = NOW() WHERE id = ?";
        $update_stmt = $conn->prepare($update_query);
        $update_stmt->bind_param("i", $user['id']);
        $update_stmt->execute();
        
        // Crear sesión
        $_SESSION['user_id'] = $user['id'];
        $_SESSION['name'] = $user['name'];
        $_SESSION['phone'] = $phone;
        
        $update_status_query = "
    INSERT INTO user_status (user_id, status, last_activity)
    VALUES (?, 'online', NOW())
    ON DUPLICATE KEY UPDATE status = 'online', last_activity = NOW()";
$stmt = $conn->prepare($update_status_query);
$stmt->bind_param("i", $_SESSION['user_id']);
$stmt->execute();
$stmt->close();
$conn->close(); // Cerrar conexión si ya no se necesita
        
        header('Location: dashboard.php');
        exit();
    } else {
        // Nuevo usuario - verificar si se proporcionó un nombre
        if (empty($name)) {
            $error = "Por favor, ingresa tu nombre para registrarte.";
        } else {
            // Insertar nuevo usuario
            $insert_query = "INSERT INTO users (phone, name) VALUES (?, ?)";
            $insert_stmt = $conn->prepare($insert_query);
            $insert_stmt->bind_param("ss", $phone, $name);
            
            if ($insert_stmt->execute()) {
                $user_id = $conn->insert_id;
                
                // Crear sesión
                $_SESSION['user_id'] = $user_id;
                $_SESSION['name'] = $name;
                $_SESSION['phone'] = $phone;
                
                header('Location: dashboard.php');
                exit();
            } else {
                $error = "Error al registrar usuario: " . $conn->error;
            }
        }
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>FlyChat - Login</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        .blue-gradient { background: linear-gradient(135deg, #0088cc 0%, #0055a5 100%); }
        .button-gradient { background: linear-gradient(135deg, #0088cc 0%, #0055a5 100%); color: white; }
        .button-gradient:hover { background: linear-gradient(135deg, #0077b3 0%, #004494 100%); }
    </style>
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <div class="flex-1 flex flex-col justify-center items-center p-6">
        <div class="w-full max-w-md bg-white rounded-xl shadow-lg overflow-hidden">
            <!-- Header -->
            <div class="blue-gradient p-6 text-center">
                <h1 class="text-white text-2xl font-bold">FlyChat</h1>
                <p class="text-blue-100 mt-1">Mensajería instantánea privada.</p>
            </div>

            <!-- Login Form Container -->
            <div class="p-6">
                <!-- Mensaje de error general -->
                <div id="error-message" class="mb-4 text-red-600 text-sm font-medium bg-red-100 p-3 rounded <?php echo isset($error) ? '' : 'hidden'; ?>">
                    <?php echo isset($error) ? $error : ''; ?>
                </div>

                <h2 class="text-xl font-semibold text-gray-800 mb-6">Iniciar sesión o registrarse</h2>
                
                <form method="post" id="login-form">
                    <!-- Contenedor para teléfono y verificación -->
                    <div id="phone-container">
                        <div class="mb-4">
                            <label class="block text-gray-700 text-sm font-medium mb-2" for="phone">
                                Número de teléfono
                            </label>
                            <div class="flex">
                                <select id="country-code" name="country_code" class="shadow-sm appearance-none border rounded-l-lg py-3 px-4 text-gray-700 leading-tight focus:outline-none focus:ring-2 focus:ring-blue-500 bg-gray-50 w-1/3">
                                    <option value="1">+1 (USA)</option>
                                    <option value="52">+52 (México)</option>
                                    <option value="34">+34 (España)</option>
                                    <option value="57" selected>+57 (Colombia)</option>
                                    <option value="54">+54 (Argentina)</option>
                                    <option value="56">+56 (Chile)</option>
                                    <option value="51">+51 (Perú)</option>
                                </select>
                                <input class="shadow-sm appearance-none border rounded-r-lg w-2/3 py-3 px-4 text-gray-700 leading-tight focus:outline-none focus:ring-2 focus:ring-blue-500"
                                    id="phone" name="phone" type="tel" placeholder="Número" autocomplete="tel-national" required>
                            </div>
                        </div>

                        <!-- Botón de verificación de teléfono -->
                        <button type="button" id="verify-button" class="w-full button-gradient font-medium py-3 px-4 rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-opacity-50 transition-colors mb-4">
                            <span id="verify-text">Verificar número</span>
                            <span id="verify-spinner" class="hidden">
                                <i class="fas fa-spinner fa-spin"></i> Verificando...
                            </span>
                        </button>
                    </div>

                    <!-- Contenedor para el nombre (inicialmente oculto) -->
                    <div id="name-container" class="mb-4 hidden">
                        <label class="block text-gray-700 text-sm font-medium mb-2" for="name">
                            Tu nombre
                        </label>
                        <input class="shadow-sm appearance-none border rounded-lg w-full py-3 px-4 text-gray-700 leading-tight focus:outline-none focus:ring-2 focus:ring-blue-500"
                            id="name" name="name" type="text" placeholder="Nombre completo" autocomplete="name">
                    </div>

                    <!-- Botón de envío del formulario (inicialmente oculto) -->
                    <button type="submit" id="login-button" class="w-full button-gradient font-medium py-3 px-4 rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-opacity-50 transition-colors hidden">
                        Continuar
                    </button>
                </form>
            </div>
        </div>
    </div>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const phoneInput = document.getElementById('phone');
            const countryCodeSelect = document.getElementById('country-code');
            const verifyButton = document.getElementById('verify-button');
            const verifyText = document.getElementById('verify-text');
            const verifySpinner = document.getElementById('verify-spinner');
            const nameContainer = document.getElementById('name-container');
            const nameInput = document.getElementById('name');
            const loginButton = document.getElementById('login-button');
            const errorMessage = document.getElementById('error-message');
            const loginForm = document.getElementById('login-form');
            
            // Función para mostrar mensajes de error
            function showError(message) {
                errorMessage.textContent = message;
                errorMessage.classList.remove('hidden');
            }
            
            // Función para ocultar mensajes de error
            function hideError() {
                errorMessage.classList.add('hidden');
            }
            
            // Función para mostrar el spinner durante la verificación
            function showSpinner() {
                verifyText.classList.add('hidden');
                verifySpinner.classList.remove('hidden');
                verifyButton.disabled = true;
            }
            
            // Función para ocultar el spinner después de la verificación
            function hideSpinner() {
                verifyText.classList.remove('hidden');
                verifySpinner.classList.add('hidden');
                verifyButton.disabled = false;
            }
            
            // Verificar el número de teléfono cuando se hace clic en el botón de verificar
            verifyButton.addEventListener('click', function() {
                hideError();
                
                // Validación básica del teléfono
                const phone = phoneInput.value.trim();
                if (phone.length < 5) {
                    showError('Por favor, ingresa un número de teléfono válido (mínimo 5 dígitos)');
                    return;
                }
                
                // Crear el número completo con código de país
                const countryCode = countryCodeSelect.value;
                const fullPhone = '+' + countryCode + phone;
                
                // Mostrar spinner durante la verificación
                showSpinner();
                
                // Verificar si el usuario existe
                fetch('check_phone.php', {
                    method: 'POST',
                    headers: {'Content-Type': 'application/x-www-form-urlencoded'},
                    body: 'phone=' + encodeURIComponent(fullPhone)
                })
                .then(response => {
                    if (!response.ok) {
                        throw new Error('Error en la conexión');
                    }
                    return response.json();
                })
                .then(data => {
                    hideSpinner();
                    
                    // Ocultar el botón de verificación
                    verifyButton.classList.add('hidden');
                    
                    if (data.exists) {
                        // Usuario existente: ocultar campo de nombre y mostrar botón de inicio
                        nameContainer.classList.add('hidden');
                        nameInput.required = false;
                        loginButton.textContent = 'Iniciar sesión';
                    } else {
                        // Nuevo usuario: mostrar campo de nombre
                        nameContainer.classList.remove('hidden');
                        nameInput.required = true;
                        nameInput.focus(); // Enfocar el campo de nombre automáticamente
                        loginButton.textContent = 'Registrarse';
                    }
                    
                    // Mostrar el botón de continuar
                    loginButton.classList.remove('hidden');
                })
                .catch(error => {
                    console.error('Error al verificar teléfono:', error);
                    hideSpinner();
                    showError('Error al verificar el número. Por favor, inténtalo de nuevo.');
                });
            });
            
            // Validación al enviar el formulario
            loginForm.addEventListener('submit', function(event) {
                const isNewUser = !nameContainer.classList.contains('hidden');
                
                if (isNewUser && nameInput.value.trim() === '') {
                    event.preventDefault();
                    showError('Por favor, ingresa tu nombre para registrarte.');
                }
            });
        });
    </script>
</body>
</html>