<?php
// send_message.php
session_start();
header('Content-Type: application/json');

// Verificar autenticación
if (!isset($_SESSION['user_id'])) {
    echo json_encode(['status' => 'error', 'message' => 'No autenticado']);
    exit();
}

// *** Log inicial para depurar error "Receptor inválido" (muy importante si persiste) ***
// Descomenta estas líneas temporalmente si sigue fallando al enviar videos
/*
if (!isset($_POST['receiver_id']) || !is_numeric($_POST['receiver_id']) || intval($_POST['receiver_id']) <= 0) {
    error_log("====== ERROR: RECEPTOR INVÁLIDO DETECTADO ======");
    error_log("Timestamp: " . date('Y-m-d H:i:s'));
    error_log("User ID (Session): " . $_SESSION['user_id']);
    error_log("Received POST data:\n" . print_r($_POST, true));
    error_log("Received FILES data:\n" . print_r($_FILES, true));
    error_log("PHP Input Stream Data (raw POST body):\n" . file_get_contents('php://input'));
    error_log("================================================");
}
*/
// *** Fin Log inicial ***


// Validar receptor (después de la autenticación)
if (!isset($_POST['receiver_id']) || !is_numeric($_POST['receiver_id']) || intval($_POST['receiver_id']) <= 0) {
    // Error ya logueado si se descomentó arriba
    echo json_encode(['status' => 'error', 'message' => 'Receptor inválido']);
    exit();
}


require_once 'config.php';

$sender_id = $_SESSION['user_id'];
$receiver_id = intval($_POST['receiver_id']);
$message_text = isset($_POST['message']) ? trim($_POST['message']) : '';


// --- Lógica de Archivo/Texto Reforzada ---
$file_attempted = isset($_FILES['file']);
$file_initial_error = $file_attempted ? $_FILES['file']['error'] : UPLOAD_ERR_NO_FILE;

// A) Verificar si el mensaje está TOTALMENTE VACÍO
// (No hay texto Y (No se intentó subir archivo O el intento falló porque no había archivo))
if (empty($message_text) && (!$file_attempted || $file_initial_error == UPLOAD_ERR_NO_FILE)) {
     error_log("send_message error: Empty message (no text and no file provided). User: $sender_id");
     echo json_encode(['status' => 'error', 'message' => 'El mensaje no puede estar vacío.']);
     exit();
}

// B) Verificar errores INICIALES de subida si se intentó subir un archivo
// (Estos errores ocurren ANTES de intentar mover el archivo)
if ($file_attempted && $file_initial_error != UPLOAD_ERR_OK && $file_initial_error != UPLOAD_ERR_NO_FILE) {
     error_log("send_message error: Initial upload error code: " . $file_initial_error . " for file: " . ($_FILES['file']['name'] ?? 'N/A') . " User: $sender_id");
     $upload_errors = [ /* ... (array de errores igual que antes) ... */ UPLOAD_ERR_INI_SIZE => "El archivo excede el límite del servidor.", UPLOAD_ERR_FORM_SIZE => "El archivo excede el límite del formulario.", UPLOAD_ERR_PARTIAL => "El archivo se subió parcialmente.", UPLOAD_ERR_NO_TMP_DIR => "Error interno: Falta carpeta temporal.", UPLOAD_ERR_CANT_WRITE => "Error interno: No se pudo escribir.", UPLOAD_ERR_EXTENSION => "Error interno: Extensión PHP.", ];
     $error_message = $upload_errors[$file_initial_error] ?? "Error desconocido durante la subida.";
     echo json_encode(['status' => 'error', 'message' => $error_message]);
     exit();
}

// --- Si llegamos aquí, o hay texto, o hay un archivo con UPLOAD_ERR_OK ---

$file_processed_successfully = false; // Cambiado nombre para claridad
$message_type = 'text'; // Default
$file_url = null; $file_name = null; $file_size = null; $file_type_mime = null;

// C) Intentar PROCESAR el archivo SI existe y tuvo UPLOAD_ERR_OK
if ($file_attempted && $file_initial_error == UPLOAD_ERR_OK) {
    $file = $_FILES['file']; $upload_dir = 'uploads/';

    // Verificar/Crear directorio
    if (!is_dir($upload_dir)) { if (!mkdir($upload_dir, 0775, true)) { error_log("Error creating upload dir: $upload_dir"); echo json_encode(['status' => 'error', 'message' => 'Error interno (dir create).']); exit(); }}
    if (!is_writable($upload_dir)) { error_log("Upload dir not writable: $upload_dir"); echo json_encode(['status' => 'error', 'message' => 'Error interno (dir perms).']); exit(); }

    // Validaciones (tamaño, tipo)
    $max_size_bytes = 50 * 1024 * 1024; // Definir límite aquí también
    if ($file['size'] > $max_size_bytes) { echo json_encode(['status' => 'error', 'message' => "Archivo muy grande (max " . ($max_size_bytes / 1024 / 1024) . " MB)."]); exit(); }
    $allowed_mime_types = [ /* ... (lista igual que antes) ... */ 'image/jpeg', 'image/png', 'image/gif', 'image/webp', 'video/mp4', 'video/webm', 'video/ogg', 'audio/mpeg', 'audio/ogg', 'audio/wav', 'application/pdf', 'text/plain', 'application/msword', 'application/vnd.openxmlformats-officedocument.wordprocessingml.document', 'application/vnd.ms-excel', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet', 'application/vnd.ms-powerpoint', 'application/vnd.openxmlformats-officedocument.presentationml.presentation', 'application/zip', 'application/x-rar-compressed', 'application/x-7z-compressed', 'application/octet-stream' ];
    $finfo = finfo_open(FILEINFO_MIME_TYPE); $mime_type = finfo_file($finfo, $file['tmp_name']); finfo_close($finfo);
    if (!in_array($mime_type, $allowed_mime_types)) { error_log("Disallowed file type: MIME=$mime_type Name=" . $file['name'] . " User:$sender_id"); echo json_encode(['status' => 'error', 'message' => 'Tipo de archivo no permitido (' . htmlspecialchars($mime_type) . ').']); exit(); }

    // Mover archivo
    $original_filename = basename($file['name']); $safe_original_name = preg_replace("/[^a-zA-Z0-9.\-_]/", "_", $original_filename); $file_extension = pathinfo($safe_original_name, PATHINFO_EXTENSION); $unique_filename = uniqid('file_', true) . ($file_extension ? '.' . strtolower($file_extension) : ''); $destination = $upload_dir . $unique_filename;
    if (move_uploaded_file($file['tmp_name'], $destination)) {
        $file_processed_successfully = true; // ¡Éxito!
        $file_url = $destination; $file_name = $safe_original_name; $file_size = $file['size']; $file_type_mime = $mime_type;
        if (strpos($file_type_mime, 'image/') === 0) $message_type = 'image'; elseif (strpos($file_type_mime, 'video/') === 0) $message_type = 'video'; elseif (strpos($file_type_mime, 'audio/') === 0) $message_type = 'audio'; else $message_type = 'file';
    } else {
        // Fallo al mover (error grave)
        $upload_error = error_get_last(); error_log("Error CRITICO al mover '$destination': " . ($upload_error['message'] ?? '?') . " - Temp: " . $file['tmp_name'] . " - Perms: " . substr(sprintf('%o', fileperms($upload_dir)), -4) . " User:$sender_id");
        echo json_encode(['status' => 'error', 'message' => 'Error interno al guardar archivo.']); exit();
    }
}

// D) Comprobación final: ¿Tenemos algo que guardar?
// (Debería ser redundante con la lógica anterior, pero por seguridad)
if (!$file_processed_successfully && empty($message_text)) {
    error_log("send_message final check fail: No text and file not processed. This shouldn't happen. User: $sender_id");
    echo json_encode(['status' => 'error', 'message' => 'Error: No hay contenido válido para enviar.']);
    exit();
}


// --- Actualizar MI estado --- (Sin cambios)
$update_my_status_query = "INSERT INTO user_status (user_id, status, last_activity) VALUES (?, 'online', NOW()) ON DUPLICATE KEY UPDATE status = 'online', last_activity = NOW()";
$update_my_stmt = $conn->prepare($update_my_status_query); if ($update_my_stmt) { $update_my_stmt->bind_param("i", $sender_id); $update_my_stmt->execute(); $update_my_stmt->close(); } else { error_log("Send_message: Error preparing update my status: " . $conn->error); }

// --- Insertar mensaje --- (Sin cambios)
$insert_query = "INSERT INTO messages (sender_id, receiver_id, message, type, file_url, file_name, file_size, file_type, timestamp, `read`, delivered) VALUES (?, ?, ?, ?, ?, ?, ?, ?, NOW(), 0, 1)";
$stmt = $conn->prepare($insert_query); if (!$stmt) { error_log("Send_message: Error preparing insert message: " . $conn->error); echo json_encode(['status' => 'error', 'message' => 'Error interno DB (prepare).']); exit(); }
$stmt->bind_param("iissssis", $sender_id, $receiver_id, $message_text, $message_type, $file_url, $file_name, $file_size, $file_type_mime);
if ($stmt->execute()) {
    $new_message_id = $stmt->insert_id; $stmt->close();
    $sent_message_query = "SELECT id, sender_id, receiver_id, message, type, file_url, file_name, file_size, file_type, timestamp, `read`, delivered FROM messages WHERE id = ?"; $sent_stmt = $conn->prepare($sent_message_query);
    if($sent_stmt){ $sent_stmt->bind_param("i", $new_message_id); $sent_stmt->execute(); $sent_message = $sent_stmt->get_result()->fetch_assoc(); $sent_stmt->close(); if ($sent_message) { echo json_encode(['status' => 'success', 'message' => $sent_message]); } else { error_log("Send_message: Error retrieving sent message ID: $new_message_id"); echo json_encode(['status' => 'error', 'message' => 'Error interno DB (retrieve).']); } }
    else { error_log("Send_message: Error preparing select sent message: " . $conn->error); echo json_encode(['status' => 'error', 'message' => 'Error interno DB (retrieve prepare).']); }
} else { error_log("Send_message: Error executing insert message: " . $stmt->error . " - Data: [S:$sender_id, R:$receiver_id, Type:$message_type, File:$file_name]"); echo json_encode(['status' => 'error', 'message' => 'Error al guardar mensaje.']); $stmt->close(); }

$conn->close();
?>