<?php
// Este script se ejecuta periódicamente mediante una tarea cron
// para actualizar automáticamente el estado de los usuarios inactivos

// Conexión a la base de datos
require_once 'config.php';

// Definir límites de tiempo para estados
$away_threshold = date('Y-m-d H:i:s', strtotime('-5 minutes')); // 5 minutos de inactividad = away
$offline_threshold = date('Y-m-d H:i:s', strtotime('-30 minutes')); // 30 minutos de inactividad = offline

// Actualizar usuarios que deberían estar en estado 'away'
$away_query = "
    UPDATE user_status 
    SET status = 'away' 
    WHERE status = 'online' 
    AND last_activity < ?
";
$away_stmt = $conn->prepare($away_query);
$away_stmt->bind_param("s", $away_threshold);
$away_stmt->execute();

// Actualizar usuarios que deberían estar en estado 'offline'
$offline_query = "
    UPDATE user_status 
    SET status = 'offline' 
    WHERE status IN ('online', 'away') 
    AND last_activity < ?
";
$offline_stmt = $conn->prepare($offline_query);
$offline_stmt->bind_param("s", $offline_threshold);
$offline_stmt->execute();

// Registro
$away_count = $away_stmt->affected_rows;
$offline_count = $offline_stmt->affected_rows;
echo "Actualizaciones de estado: {$away_count} usuarios marcados como 'away', {$offline_count} usuarios marcados como 'offline'\n";

$conn->close();
?>